@@ -1,5 +1,5 @@
 from .query import get_filtration
-from .filtration import FiltrationData
+from .filtration import FiltrationData, ParsingData
 from .table import DataTable
 from .operations import FiltrationOperator
 from .schemas import Filterable, Filter
