@@ -214,6 +214,7 @@ AnyFiltrationOperator = Union[FiltrationOperator, str]
 def get_filtration(
     valid_columns: Iterable[str],
     *,
+    default_filtration_class: type[FiltrationData] = FiltrationData,
     operator_data: Optional[
         dict[
             str,
@@ -265,7 +266,7 @@ def get_filtration(
                 f"Valid columns: {', '.join(valid_columns)}",
             )
 
-        return FiltrationData(
+        return default_filtration_class(
             to_filter=parser.parse(request.query_params),
             limit=limit,
             offset=offset,
